# Monster Scanner Skill

## About

A skill to help your children feel safe at night by scanning for monsters under the bed.

## Configuration

If you feel like being a monster yourself, you can set `scary` in the config to `true` and the skill will sometimes find a monster.

Under skill settings (`~/.config/mycroft/skills/skill-monster-scanner.mikejgray/settings.json`):

| Option  | Value   | Description                                                  |
| ------- | ------- | ------------------------------------------------------------ |
| `scary` | `false` | Whether or not to occasionally find a monster under the bed. |

Note: If you are running Neon, the skill settings file will be located at `~/.config/neon/skills/skill-monster-scanner.mikejgray/settings.json`.

## Examples

- "Are there monsters under my bed?"
- "Is the Boogeyman under the bed?"

## Credits

- Mike Gray (@mikejgray)

## Category

Fun

## Tags

ovos skill neon skill monster scanner kids children fun silly
